@@ -1,4 +1,4 @@
-# Copyright 2020 AstroLab Software
+# Copyright 2020-2022 AstroLab Software
 # Author: Julien Peloton
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -25,11 +25,12 @@ import os
 from fink_science import __file__
 from fink_science.conversion import mag2fluxcal_snana
 from fink_science.snn.utilities import reformat_to_df
+from fink_science.snn.utilities import return_list_of_sn_host
 
 from fink_science.tester import spark_unit_tests
 
 @pandas_udf(DoubleType(), PandasUDFType.SCALAR)
-def snn_ia(candid, jd, fid, magpsf, sigmapsf, model_name, model_ext=None) -> pd.Series:
+def snn_ia(candid, jd, fid, magpsf, sigmapsf, roid, cdsxmatch, jdstarthist, model_name, model_ext=None) -> pd.Series:
     """ Compute probabilities of alerts to be SN Ia using SuperNNova
 
     Parameters
@@ -56,11 +57,17 @@ def snn_ia(candid, jd, fid, magpsf, sigmapsf, model_name, model_ext=None) -> pd.
 
     Examples
     ----------
+    >>> from fink_science.xmatch.processor import cdsxmatch
+    >>> from fink_science.asteroids.processor import roid_catcher
     >>> from fink_science.utilities import concat_col
     >>> from pyspark.sql import functions as F
 
     >>> df = spark.read.load(ztf_alert_sample)
 
+    # Add SIMBAD field
+    >>> colnames = [df['objectId'], df['candidate.ra'], df['candidate.dec']]
+    >>> df = df.withColumn('cdsxmatch', cdsxmatch(*colnames))
+
     # Required alert columns
     >>> what = ['jd', 'fid', 'magpsf', 'sigmapsf']
 
@@ -72,23 +79,44 @@ def snn_ia(candid, jd, fid, magpsf, sigmapsf, model_name, model_ext=None) -> pd.
     >>> for colname in what:
     ...    df = concat_col(df, colname, prefix=prefix)
 
+    # Add SSO field
+    >>> args_roid = [
+    ...    'cjd', 'cmagpsf',
+    ...    'candidate.ndethist', 'candidate.sgscore1',
+    ...    'candidate.ssdistnr', 'candidate.distpsnr1']
+    >>> df = df.withColumn('roid', roid_catcher(*args_roid))
+
     # Perform the fit + classification (default model)
-    >>> args = ['candid', 'cjd', 'cfid', 'cmagpsf', 'csigmapsf', F.lit('snn_snia_vs_nonia')]
+    >>> args = ['candid', 'cjd', 'cfid', 'cmagpsf', 'csigmapsf']
+    >>> args += [F.col('roid'), F.col('cdsxmatch'), F.col('candidate.jdstarthist')]
+    >>> args += [F.lit('snn_snia_vs_nonia')]
     >>> df = df.withColumn('pIa', snn_ia(*args))
 
-    >>> df.agg({"pIa": "min"}).collect()[0][0] >= 0.0
-    True
+    >>> df.filter(df['pIa'] > 0.5).count()
+    7
 
     # Note that we can also specify a model
-    >>> args = [F.col(i) for i in ['candid', 'cjd', 'cfid', 'cmagpsf', 'csigmapsf']] + [F.lit(''), F.lit(model_path)]
+    >>> args = [F.col(i) for i in ['candid', 'cjd', 'cfid', 'cmagpsf', 'csigmapsf']]
+    >>> args += [F.col('roid'), F.col('cdsxmatch'), F.col('candidate.jdstarthist')]
+    >>> args += [F.lit(''), F.lit(model_path)]
     >>> df = df.withColumn('pIa', snn_ia(*args))
 
-    >>> df.agg({"pIa": "min"}).collect()[0][0] >= 0.0
-    True
-
-    >>> df.agg({"pIa": "max"}).collect()[0][0] < 1.0
-    True
+    >>> df.filter(df['pIa'] > 0.5).count()
+    7
     """
+    # Flag empty alerts
+    mask = magpsf.apply(lambda x: np.sum(np.array(x) == np.array(x))) > 1
+
+    mask *= jd.apply(lambda x: float(x[-1])) - jdstarthist.astype(float) <= 90
+
+    mask *= roid.astype(int) != 3
+
+    list_of_sn_host = return_list_of_sn_host()
+    mask *= cdsxmatch.apply(lambda x: x in list_of_sn_host)
+
+    if len(jd[mask]) == 0:
+        return pd.Series(np.zeros(len(jd), dtype=float))
+
     if model_ext is not None:
         # take the first element of the Series
         model = model_ext.values[0]
@@ -100,8 +128,8 @@ def snn_ia(candid, jd, fid, magpsf, sigmapsf, model_name, model_ext=None) -> pd.
     # add an exploded column with SNID
     df_tmp = pd.DataFrame.from_dict(
         {
-            'jd': jd,
-            'SNID': [str(i) for i in candid.values]
+            'jd': jd[mask],
+            'SNID': [str(i) for i in candid[mask].values]
         }
     )
 
@@ -109,8 +137,8 @@ def snn_ia(candid, jd, fid, magpsf, sigmapsf, model_name, model_ext=None) -> pd.
 
     # compute flux and flux error
     data = [mag2fluxcal_snana(*args) for args in zip(
-        magpsf.explode(),
-        sigmapsf.explode())]
+        magpsf[mask].explode(),
+        sigmapsf[mask].explode())]
     flux, error = np.transpose(data)
 
     # make a Pandas DataFrame with exploded series
@@ -119,7 +147,7 @@ def snn_ia(candid, jd, fid, magpsf, sigmapsf, model_name, model_ext=None) -> pd.
         'MJD': df_tmp['jd'],
         'FLUXCAL': flux,
         'FLUXCALERR': error,
-        'FLT': fid.explode().replace({1: 'g', 2: 'r'})
+        'FLT': fid[mask].explode().replace({1: 'g', 2: 'r'})
     })
 
     # Compute predictions
@@ -128,10 +156,14 @@ def snn_ia(candid, jd, fid, magpsf, sigmapsf, model_name, model_ext=None) -> pd.
     # Reformat and re-index
     preds_df = reformat_to_df(pred_probs, ids=ids)
     preds_df.index = preds_df.SNID
-    ia = preds_df.reindex([str(i) for i in candid.values])
+
+    # Take only probabilities to be Ia
+    to_return = np.zeros(len(jd), dtype=float)
+    ia = preds_df.reindex([str(i) for i in candid[mask].values])
+    to_return[mask] = ia.prob_class0.values
 
     # return probabilities to be Ia
-    return ia.prob_class0
+    return pd.Series(to_return)
 
 
 if __name__ == "__main__":
@@ -140,7 +172,7 @@ if __name__ == "__main__":
     globs = globals()
     path = os.path.dirname(__file__)
 
-    ztf_alert_sample = 'file://{}/data/alerts/alerts.parquet'.format(path)
+    ztf_alert_sample = 'file://{}/data/alerts/datatest'.format(path)
     globs["ztf_alert_sample"] = ztf_alert_sample
 
     model_path = '{}/data/models/snn_models/snn_sn_vs_all/model.pt'.format(path)
